@@ -94,7 +94,7 @@ class Action:
         Registers a new instance or returns an existing instance if the action is already registered.
 
         :param action: action method
-        :return: SchedulerAction instance
+        :return: Action instance
         """
         # todo catch, passthrough, or assign args and kwargs
         # todo consider logging that a new action has been registered
@@ -118,6 +118,18 @@ class Action:
                 action
             )
 
+    @classmethod
+    def register_actions(cls, *actions: Union[str, Callable, "Action"]) -> List["Action"]:
+        """
+        Registers multiple actions
+
+        :param actions: action methods to be registered
+        :return: list of actions which were registered
+        """
+        return [
+            cls.register_action(action) for action in actions
+        ]
+
     @classmethod
     def get_registered_actions(cls) -> List["Action"]:
         """returns a list of registered Scheduler Actions"""
@@ -192,6 +204,7 @@ class ConfiguredAction:
         self._action: Action = None
         # register action and store attribute
         self.action = action
+        # todo inspect provided action for default kwargs and store values
         self.args = _update_args(self.action.default_args, args)
         self.kwargs = _update_kwargs(self.action.default_kwargs, kwargs)
 
