@@ -7,7 +7,7 @@ import datetime
 import uuid
 from typing import List, Union, Iterable
 from .timepoint import ActionTimePoint
-from .action import Action
+from .action import Action, ConfiguredAction
 
 logger = logging.getLogger(__name__)
 
@@ -46,7 +46,7 @@ class SamplingScheduler(object):
         self._killswitch = threading.Event()
 
         # store default actions
-        self._default_actions = []
+        self._default_actions: List[ConfiguredAction] = []
 
         # time stamp for Scheduler creation
         self.created = time.time()
@@ -194,6 +194,11 @@ class SamplingScheduler(object):
         except IndexError:
             raise IndexError(f'The {cls.__name__} has no instances. ')
 
+    @property
+    def default_actions(self) -> List[ConfiguredAction]:
+        """list of default actions associated with the Scheduler"""
+        return self._default_actions
+
     def _determine_actions(self,
                            additional_actions: Iterable[Union[str, callable, ActionTimePoint]] = None,
                            specified_actions: Iterable[Union[str, callable, ActionTimePoint]] = None,
@@ -318,7 +323,7 @@ class SamplingScheduler(object):
                 time.sleep(0.5)
 
     def add_default_action(self,
-                           action: Union[str, callable, Action],
+                           action: Union[str, callable, Action, ConfiguredAction],
                            # location: int = None,  # todo add support for order specification (location)
                            ):
         """
@@ -329,11 +334,13 @@ class SamplingScheduler(object):
         # perform callable check
         if callable(action) is False:
             raise TypeError(f'The provided action {action} is not callable.')
-        if action in self._default_actions:
-            raise ValueError(f'The action {action} is already in the list of actions')
+
+        # if not a configured action, create instance
+        if isinstance(action, ConfiguredAction) is False:
+            action = ConfiguredAction(action)
 
         self._default_actions.append(
-            Action.register_action(action)
+            action
         )
         for tp in self._time_points:
             if tp.triggered is False:
